@@ -16,6 +16,9 @@ class PaymentGatewayApp(BaseApp):
         "MITOL_PAYMENT_GATEWAY_CYBERSOURCE_PROFILE_ID",
         "MITOL_PAYMENT_GATEWAY_CYBERSOURCE_SECURITY_KEY",
         "MITOL_PAYMENT_GATEWAY_CYBERSOURCE_SECURE_ACCEPTANCE_URL",
+        "MITOL_PAYMENT_GATEWAY_CYBERSOURCE_MERCHANT_ID",
+        "MITOL_PAYMENT_GATEWAY_CYBERSOURCE_MERCHANT_SECRET",
+        "MITOL_PAYMENT_GATEWAY_CYBERSOURCE_MERCHANT_SECRET_KEY_ID",
     ]
 
     # necessary because this is a namespaced app
